@@ -5,7 +5,7 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
     use Carp qw[];
     use Config qw[%Config];
     use lib '../../../../../';
-    use inc::MBX::Alien::FLTK::Utility qw[_o _a _rel _abs can_run];
+    use inc::MBX::Alien::FLTK::Utility qw[_o _a _rel _abs can_run _path];
     use inc::MBX::Alien::FLTK;
     use base 'inc::MBX::Alien::FLTK::Base';
     $|++;
@@ -28,6 +28,7 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
         #$self->notes('define')->{'HAVE_SYS_DIR_H'}  = undef;
         #$self->notes('define')->{'HAVE_NDIR_H'}     = undef;
         $self->notes('define')->{'HAVE_SCANDIR'} = undef;
+        $self->notes('define')->{'HAVE_DIRENT'}  = 0;
     GL: {
             last if grep {m[^no_gl$]} @args;
             print 'Testing GL Support... ';
